URLStateExtractor class

Constructors

URLStateExtractor(String url)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNFC bool
no setter
hasNFCE bool
no setter
hasNFE bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

extractState() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited